/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'iframe', 'vi', {
	border: 'Hiển thị viền khung',
	noUrl: 'Vui lòng nhập địa chỉ iframe',
	scrolling: 'Kích hoạt thanh cuộn',
	title: 'Thuộc tính iframe',
	toolbar: 'Iframe',
	tabindex: 'Remove from tabindex' // MISSING
} );
